<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://nasirahmed.com
 * @since      1.0.0
 *
 * @package    Form_To_Sheet
 * @subpackage Form_To_Sheet/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Form_To_Sheet
 * @subpackage Form_To_Sheet/includes
 * @author     Nasir Ahmed <nasir9bd@gmail.com>
 */
class Form_To_Sheet {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Form_To_Sheet_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'FORM_TO_SHEET_VERSION' ) ) {
			$this->version = FORM_TO_SHEET_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'form-to-sheet';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-form-to-sheet-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-form-to-sheet-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-form-to-sheet-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-form-to-sheet-public.php';

		$this->loader = new Form_To_Sheet_Loader();

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-form-to-sheet-relation.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-form-to-sheet-settings.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/form-to-sheet-cf7.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/form-to-sheet-gsheet.php';


		do_action( 'form_to_sheet_load_dependencies' );
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Form_To_Sheet_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Form_To_Sheet_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin     = new Form_To_Sheet_Admin( $this->get_plugin_name(), $this->get_version() );
		$fts_google_sheet = new Form_To_Sheet_GSheet2( $this->get_plugin_name(), $this->get_version() );
		$fts_relations    = new Form_To_Sheet_Relation( $this->get_plugin_name(), $this->get_version(), $fts_google_sheet );

		$this->loader->add_action( 'admin_enqueue_scripts', $fts_relations, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $fts_relations, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $fts_relations, 'fts_menu_pages' );
		$this->loader->add_action( 'admin_post_fts_save_submitted_relations', $fts_relations,'fts_save_submitted_relations' );
		$this->loader->add_action( 'admin_post_fts_update_relations', $fts_relations,'fts_update_relations' );
		$this->loader->add_action( 'wp_ajax_fts_action', $fts_relations,'fts_action');
		$this->loader->add_action( 'wp_ajax_fts_get_worksheets', $fts_relations,'fts_get_worksheets');
		$this->loader->add_action( 'wp_ajax_fts_get_forms', $fts_relations,'fts_get_forms');
		$this->loader->add_action( 'wp_ajax_fts_get_form_fields', $fts_relations,'fts_get_form_fields');
		$this->loader->add_action( 'wp_ajax_fts_get_spreadsheets', $fts_relations,'fts_get_spreadsheets');

		$fts_settings = new Form_To_Sheet_Settings( $this->get_plugin_name(), $this->get_version(), $fts_google_sheet);
		$this->loader->add_action( 'admin_menu', $fts_settings,'fts_submenu_pages' );
		$this->loader->add_action( 'admin_enqueue_scripts', $fts_settings, 'enqueue_styles' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Form_To_Sheet_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public,'enqueue_styles');
		$this->loader->add_action('wp_enqueue_scripts',$plugin_public,'enqueue_scripts');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Form_To_Sheet_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
